;;; hepburn.el --- Hepburn Roman to Kana database

;; Copyright (C) 1996 MORIOKA Tomohiko

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Version: $Id: hepburn.el,v 0.4 1996/09/18 09:38:02 morioka Exp $
;; Keywords: Roman-to-Kana, input, Japanese, mule

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(defvar hepburn-roman-to-kana-translation-rule-alist
  '(("a" . "$B$"(B")
    ("i" . "$B$$(B")
    ("u" . "$B$&(B")
    ("e" . "$B$((B")
    ("o" . "$B$*(B")
    
    ("ka" . "$B$+(B")("kka" . "$B$C$+(B")
    ("ki" . "$B$-(B")("kki" . "$B$C$-(B")
    ("ku" . "$B$/(B")("kku" . "$B$C$/(B")
    ("ke" . "$B$1(B")("kke" . "$B$C$1(B")
    ("ko" . "$B$3(B")("kko" . "$B$C$3(B")
    
    ("ga" . "$B$,(B")("gga" . "$B$C$,(B")
    ("gi" . "$B$.(B")("ggi" . "$B$C$.(B")
    ("gu" . "$B$0(B")("ggu" . "$B$C$0(B")
    ("ge" . "$B$2(B")("gge" . "$B$C$2(B")
    ("go" . "$B$4(B")("ggo" . "$B$C$4(B")
    
    ("kya" . "$B$-$c(B")("kkya" . "$B$C$-$c(B")
    ("kyi" . "$B$-$#(B")("kkyi" . "$B$C$-$#(B")
    ("kyu" . "$B$-$e(B")("kkyu" . "$B$C$-$e(B")
    ("kye" . "$B$-$'(B")("kkye" . "$B$C$-$'(B")
    ("kyo" . "$B$-$g(B")("kkyo" . "$B$C$-$g(B")
    
    ("gya" . "$B$.$c(B")("ggya" . "$B$C$.$c(B")
    ("gyi" . "$B$.$#(B")("ggyi" . "$B$C$.$#(B")
    ("gyu" . "$B$.$e(B")("ggyu" . "$B$C$.$e(B")
    ("gye" . "$B$.$'(B")("ggye" . "$B$C$.$'(B")
    ("gyo" . "$B$.$g(B")("ggyo" . "$B$C$.$g(B")
    
    ("sa" . "$B$5(B")("ssa" . "$B$C$5(B")
    ("si" . "$B$7(B")("ssi" . "$B$C$7(B")
    ("su" . "$B$9(B")("ssu" . "$B$C$9(B")
    ("se" . "$B$;(B")("sse" . "$B$C$;(B")
    ("so" . "$B$=(B")("sso" . "$B$C$=(B")
    
    ("za" . "$B$6(B")("zza" . "$B$C$6(B")
    ("zi" . "$B$8(B")("zzi" . "$B$C$8(B")
    ("zu" . "$B$:(B")("zzu" . "$B$C$:(B")
    ("ze" . "$B$<(B")("zze" . "$B$C$<(B")
    ("zo" . "$B$>(B")("zzo" . "$B$C$>(B")
    
    ("sha" . "$B$7$c(B")("ssha" . "$B$C$7$c(B")
    ("shi" . "$B$7(B")  ("sshi" . "$B$C$7(B")
    ("shu" . "$B$7$e(B")("sshu" . "$B$C$7$e(B")
    ("she" . "$B$7$'(B")("sshe" . "$B$C$7$'(B")
    ("sho" . "$B$7$g(B")("ssho" . "$B$C$7$g(B")
    
    ("ja" . "$B$8$c(B")("jja" . "$B$C$8$c(B")
    ("ji" . "$B$8(B")  ("jji" . "$B$C$8(B")
    ("ju" . "$B$8$e(B")("jju" . "$B$C$8$e(B")
    ("je" . "$B$8$'(B")("jje" . "$B$C$8$'(B")
    ("jo" . "$B$8$g(B")("jjo" . "$B$C$8$g(B")
    
    ("ta" . "$B$?(B")  ("tta" . "$B$C$?(B")
    ("ti" . "$B$F$#(B")("tti" . "$B$C$F$#(B")
    ("tu" . "$B$H$%(B")("ttu" . "$B$C$H$%(B")
    ("te" . "$B$F(B")  ("tte" . "$B$C$F(B")
    ("to" . "$B$H(B")  ("tto" . "$B$C$H(B")
    
    ("da" . "$B$@(B")  ("dda" . "$B$C$@(B")
    ("di" . "$B$G$#(B")("ddi" . "$B$C$G$#(B")
    ("du" . "$B$E(B")  ("ddu" . "$B$C$E(B")
    ("de" . "$B$G(B")  ("dde" . "$B$C$G(B")
    ("do" . "$B$I(B")  ("ddo" . "$B$C$I(B")
    
    ("tsa" . "$B$D$!(B")("ttsa" . "$B$C$D$!(B")
    ("tsi" . "$B$D$#(B")("ttsi" . "$B$C$D$#(B")
    ("tsu" . "$B$D(B")  ("ttsu" . "$B$C$D(B")
    ("tse" . "$B$D$'(B")("ttse" . "$B$C$D$'(B")
    ("tso" . "$B$D$)(B")("ttso" . "$B$C$D$)(B")
    
    ("dza" . "$B$E$!(B")("ddza" . "$B$C$E$!(B")
    ("dzi" . "$B$E$#(B")("ddzi" . "$B$C$E$#(B")
    ("dzu" . "$B$E(B")  ("ddzu" . "$B$C$E(B")
    ("dze" . "$B$E$'(B")("ddze" . "$B$C$E$'(B")
    ("dzo" . "$B$E$)(B")("ddzo" . "$B$C$E$)(B")
    
    ("cha" . "$B$A$c(B")("ccha" . "$B$C$A$c(B")
    ("chi" . "$B$A(B")  ("cchi" . "$B$C$A(B")
    ("chu" . "$B$A$e(B")("cchu" . "$B$C$A$e(B")
    ("che" . "$B$A$'(B")("cche" . "$B$C$A$'(B")
    ("cho" . "$B$A$g(B")("ccho" . "$B$C$A$g(B")
    
    ("dja" . "$B$B$c(B")("ddja" . "$B$C$B$c(B")
    ("dji" . "$B$B(B")  ("ddji" . "$B$C$B(B")
    ("dju" . "$B$B$e(B")("ddju" . "$B$C$B$e(B")
    ("dje" . "$B$B$'(B")("ddje" . "$B$C$B$'(B")
    ("djo" . "$B$B$g(B")("ddjo" . "$B$C$B$g(B")
    
    ("na" . "$B$J(B")("nna" . "$B$s$J(B")
    ("ni" . "$B$K(B")("nni" . "$B$s$K(B")
    ("nu" . "$B$L(B")("nnu" . "$B$s$L(B")
    ("ne" . "$B$M(B")("nne" . "$B$s$M(B")
    ("no" . "$B$N(B")("nno" . "$B$s$N(B")
    
    ("nya" . "$B$K$c(B")("nnya" . "$B$C$K$c(B")
    ("nyi" . "$B$K$#(B")("nnyi" . "$B$C$K$#(B")
    ("nyu" . "$B$K$e(B")("nnyu" . "$B$C$K$e(B")
    ("nye" . "$B$K$'(B")("nnye" . "$B$C$K$'(B")
    ("nyo" . "$B$K$g(B")("nnyo" . "$B$C$K$g(B")
        
    ("ha" . "$B$O(B")("hha" . "$B$C$O(B")
    ("hi" . "$B$R(B")("hhi" . "$B$C$R(B")
    ("hu" . "$B$U(B")("hhu" . "$B$C$U(B")
    ("he" . "$B$X(B")("hhe" . "$B$C$X(B")
    ("ho" . "$B$[(B")("hho" . "$B$C$[(B")
    
    ("pa" . "$B$Q(B")("ppa" . "$B$C$Q(B")
    ("pi" . "$B$T(B")("ppi" . "$B$C$T(B")
    ("pu" . "$B$W(B")("ppu" . "$B$C$W(B")
    ("pe" . "$B$Z(B")("ppe" . "$B$C$Z(B")
    ("po" . "$B$](B")("ppo" . "$B$C$](B")
    
    ("ba" . "$B$P(B")("bba" . "$B$C$P(B")
    ("bi" . "$B$S(B")("bbi" . "$B$C$S(B")
    ("bu" . "$B$V(B")("bbu" . "$B$C$V(B")
    ("be" . "$B$Y(B")("bbe" . "$B$C$Y(B")
    ("bo" . "$B$\(B")("bbo" . "$B$C$\(B")
    
    ("hya" . "$B$R$c(B")("hhya" . "$B$C$R$c(B")
    ("hyi" . "$B$R$#(B")("hhyi" . "$B$C$R$#(B")
    ("hyu" . "$B$R$e(B")("hhyu" . "$B$C$R$e(B")
    ("hye" . "$B$R$'(B")("hhye" . "$B$C$R$'(B")
    ("hyo" . "$B$R$g(B")("hhyo" . "$B$C$R$g(B")
    
    ("pya" . "$B$T$c(B")("ppya" . "$B$C$T$c(B")
    ("pyi" . "$B$T$#(B")("ppyi" . "$B$C$T$#(B")
    ("pyu" . "$B$T$e(B")("ppyu" . "$B$C$T$e(B")
    ("pye" . "$B$T$'(B")("ppye" . "$B$C$T$'(B")
    ("pyo" . "$B$T$g(B")("ppyo" . "$B$C$T$g(B")
    
    ("bya" . "$B$S$c(B")("bbya" . "$B$C$S$c(B")
    ("byi" . "$B$S$#(B")("bbyi" . "$B$C$S$#(B")
    ("byu" . "$B$S$e(B")("bbyu" . "$B$C$S$e(B")
    ("bye" . "$B$S$'(B")("bbye" . "$B$C$S$'(B")
    ("byo" . "$B$S$g(B")("bbyo" . "$B$C$S$g(B")
    
    ("fa" . "$B$U$!(B")("ffa" . "$B$C$U$!(B")
    ("fi" . "$B$U$#(B")("ffi" . "$B$C$U$#(B")
    ("fu" . "$B$U(B")  ("ffu" . "$B$C$U(B")
    ("fe" . "$B$U$'(B")("ffe" . "$B$C$U$'(B")
    ("fo" . "$B$U$)(B")("ffo" . "$B$C$U$)(B")
    
    ("pfa" . "$B$W$!(B")("ppfa" . "$B$C$W$!(B")
    ("pfi" . "$B$W$#(B")("ppfi" . "$B$C$W$#(B")
    ("pfu" . "$B$W(B")  ("ppfu" . "$B$C$W(B")
    ("pfe" . "$B$W$'(B")("ppfe" . "$B$C$W$'(B")
    ("pfo" . "$B$W$)(B")("ppfo" . "$B$C$W$)(B")
    
    ("va" . "$B%t$!(B")("vva" . "$B$C%t$!(B")
    ("vi" . "$B%t$#(B")("vvi" . "$B$C%t$#(B")
    ("vu" . "$B%t(B")  ("vvu" . "$B$C%t(B")
    ("ve" . "$B%t$'(B")("vve" . "$B$C%t$'(B")
    ("vo" . "$B%t$)(B")("vvo" . "$B$C%t$)(B")
    
    ("ma" . "$B$^(B")("mma" . "$B$C$^(B")
    ("mi" . "$B$_(B")("mmi" . "$B$C$_(B")
    ("mu" . "$B$`(B")("mmu" . "$B$C$`(B")
    ("me" . "$B$a(B")("mme" . "$B$C$a(B")
    ("mo" . "$B$b(B")("mmo" . "$B$C$b(B")
    
    ("mya" . "$B$_$c(B")("mmya" . "$B$C$_$c(B")
    ("myi" . "$B$_$#(B")("mmyi" . "$B$C$_$#(B")
    ("myu" . "$B$_$e(B")("mmyu" . "$B$C$_$e(B")
    ("mye" . "$B$_$'(B")("mmye" . "$B$C$_$'(B")
    ("myo" . "$B$_$g(B")("mmyo" . "$B$C$_$g(B")
    
    ("ya" . "$B$d(B")  ("yya" . "$B$C$d(B")
    ("yi" . "$B$$(B")  ("yyi" . "$B$C$$(B")
    ("yu" . "$B$f(B")  ("yyu" . "$B$C$f(B")
    ("ye" . "$B$$$'(B")("yye" . "$B$C$$$'(B")
    ("yo" . "$B$h(B")  ("yyo" . "$B$C$h(B")
    
    ("ra" . "$B$i(B")("rra" . "$B$C$i(B")
    ("ri" . "$B$j(B")("rri" . "$B$C$j(B")
    ("ru" . "$B$k(B")("rru" . "$B$C$k(B")
    ("re" . "$B$l(B")("rre" . "$B$C$l(B")
    ("ro" . "$B$m(B")("rro" . "$B$C$m(B")
    
    ("rya" . "$B$j$c(B")("rrya" . "$B$C$j$c(B")
    ("ryi" . "$B$j$#(B")("rryi" . "$B$C$j$#(B")
    ("ryu" . "$B$j$e(B")("rryu" . "$B$C$j$e(B")
    ("rye" . "$B$j$'(B")("rrye" . "$B$C$j$'(B")
    ("ryo" . "$B$j$g(B")("rryo" . "$B$C$j$g(B")
    
    ("wa" . "$B$o(B")("wwa" . "$B$C$o(B")
    ("wi" . "$B$p(B")("wwi" . "$B$C$p(B")
    ("wu" . "$B$&(B")("wwu" . "$B$C$&(B")
    ("we" . "$B$q(B")("wwe" . "$B$C$q(B")
    ("wo" . "$B$r(B")("wwo" . "$B$C$r(B")
    
    ("n'" . "$B$s(B")
    ("n" . "$B$s(B")
    ("x" . "$B$s(B")
    ("q" . "$B$C(B")

    ("1" . "$B#1(B") ("2" . "$B#2(B") ("3" . "$B#3(B") ("4" . "$B#4(B") ("5" . "$B#5(B")
    ("6" . "$B#6(B") ("7" . "$B#7(B") ("8" . "$B#8(B") ("9" . "$B#9(B") ("0" . "$B#0(B")

    ("!" . "$B!*(B") ("@" . "$B!w(B") ("#" . "$B!t(B") ("$" . "$B!p(B") ("%" . "$B!s(B")
    ("^" . "$B!0(B") ("&" . "$B!u(B") ("*" . "$B!v(B") ("(" . "$B!J(B") (")" . "$B!K(B")
    ("-" . "$B!<(B") ("=" . "$B!a(B") ("`" . "$B!.(B") ("\\" . "$B!@(B")("|" . "$B!C(B")
    ("_" . "$B!2(B") ("+" . "$B!\(B") ("~" . "$B!1(B") ("[" . "$B!V(B") ("]" . "$B!W(B")
    ("{" . "$B!P(B") ("}" . "$B!Q(B") (":" . "$B!'(B") (";" . "$B!((B") ("\""  "$B!I(B")
    ("'" . "$B!G(B") ("." . "$B!#(B") ("," . "$B!"(B") ("<" . "$B!c(B") (">" . "$B!d(B")
    ("?" . "$B!)(B") ("/" . "$B!?(B")

    ("z1" . "$B!{(B") ("z!" . "$B!|(B")
    ("z2" . "$B"&(B") ("z@" . "$B"'(B")
    ("z3" . "$B"$(B") ("z#" . "$B"%(B")
    ("z4" . "$B""(B") ("z$" . "$B"#(B")
    ("z5" . "$B!~(B") ("z%" . "$B"!(B")
    ("z6" . "$B!y(B") ("z^" . "$B!z(B")
    ("z7" . "$B!}(B") ("z&" . "$B!r(B")
    ("z8" . "$B!q(B") ("z*" . "$B!_(B")
    ("z9" . "$B!i(B") ("z(" . "$B!Z(B")
    ("z0" . "$B!j(B") ("z)" . "$B![(B")
    ("z-" . "$B!A(B") ("z_" . "$B!h(B")
    ("z=" . "$B!b(B") ("z+" . "$B!^(B")
    ("z\\" . "$B!o(B")("z|" . "$B!B(B")
    ("z`" . "$B!-(B") ("z~" . "$B!/(B")
    
    ("zq" . "$B!T(B") ("zQ" . "$B!R(B")
    ("zw" . "$B!U(B") ("zW" . "$B!S(B")
    ("zr" . "$B!9(B") ("zR" . "$B!8(B")
    ("zt" . "$B!:(B") ("zT" . "$B!x(B")
    ("zp" . "$B")(B") ("zP" . "$B",(B")
    ("z[" . "$B!X(B") ("z{" . "$B!L(B")
    ("z]" . "$B!Y(B") ("z}" . "$B!M(B")
    
    ("zs" . "$B!3(B") ("zS" . "$B!4(B")
    ("zd" . "$B!5(B") ("zD" . "$B!6(B")
    ("zf" . "$B!7(B") ("zF" . "$B"*(B")
    ("zg" . "$B!>(B") ("zG" . "$B!=(B")
    ("zh" . "$B"+(B")
    ("zj" . "$B"-(B")
    ("zk" . "$B",(B")
    ("zl" . "$B"*(B")
    ("z;" . "$B!+(B") ("z:" . "$B!,(B")
    ("z\'" . "$B!F(B")("z\"" . "$B!H(B")
    
    ("zx" . ":-") ("zX" . ":-)")
    ("zc" . "$B!;(B") ("zC" . "$B!n(B")
    ("zv" . "$B"((B") ("zV" . "$B!`(B")
    ("zb" . "$B!k(B") ("zB" . "$B"+(B")
    ("zn" . "$B!l(B") ("zN" . "$B"-(B")
    ("zm" . "$B!m(B") ("zM" . "$B".(B")
    ("z," . "$B!E(B") ("z<" . "$B!e(B")
    ("z." . "$B!D(B") ("z>" . "$B!f(B")
    ("z/" . "$B!&(B") ("z?" . "$B!g(B")
    
    ("Z " "$B!!(B") ("Z!" "$B!*(B") ("Z\"" "$B!m(B") ("Z#" "$B!t(B")
    ("Z$" "$B!p(B") ("Z%" "$B!s(B") ("Z&" "$B!u(B") ("Z'" "$B!l(B")
    ("Z(" "$B!J(B") ("Z)" "$B!K(B") ("Z*" "$B!v(B") ("Z+" "$B!\(B")
    ("Z," "$B!$(B") ("Z-" "$B!](B") ("Z." "$B!%(B") ("Z/" "$B!?(B")
    ("Z0" "$B#0(B") ("Z1" "$B#1(B") ("Z2" "$B#2(B") ("Z3" "$B#3(B")
    ("Z4" "$B#4(B") ("Z5" "$B#5(B") ("Z6" "$B#6(B") ("Z7" "$B#7(B")
    ("Z8" "$B#8(B") ("Z9" "$B#9(B") ("Z:" "$B!'(B") ("Z;" "$B!((B")
    ("Z<" "$B!c(B") ("Z=" "$B!a(B") ("Z>" "$B!d(B") ("Z?" "$B!)(B")
    ("Z@" "$B!w(B") ("ZA" "$B#A(B") ("ZB" "$B#B(B") ("ZC" "$B#C(B")
    ("ZD" "$B#D(B") ("ZE" "$B#E(B") ("ZF" "$B#F(B") ("ZG" "$B#G(B")
    ("ZH" "$B#H(B") ("ZI" "$B#I(B") ("ZJ" "$B#J(B") ("ZK" "$B#K(B")
    ("ZL" "$B#L(B") ("ZM" "$B#M(B") ("ZN" "$B#N(B") ("ZO" "$B#O(B")
    ("ZP" "$B#P(B") ("ZQ" "$B#Q(B") ("ZR" "$B#R(B") ("ZS" "$B#S(B")
    ("ZT" "$B#T(B") ("ZU" "$B#U(B") ("ZV" "$B#V(B") ("ZW" "$B#W(B")
    ("ZX" "$B#X(B") ("ZY" "$B#Y(B") ("ZZ" "$B#Z(B") ("Z[" "$B!N(B")
    ("Z\\" "$B!@(B")("Z]" "$B!O(B") ("Z^" "$B!0(B") ("Z_" "$B!2(B")
    ("Z`" "$B!F(B") ("Za" "$B#a(B") ("Zb" "$B#b(B") ("Zc" "$B#c(B")
    ("Zd" "$B#d(B") ("Ze" "$B#e(B") ("Zf" "$B#f(B") ("Zg" "$B#g(B")
    ("Zh" "$B#h(B") ("Zi" "$B#i(B") ("Zj" "$B#j(B") ("Zk" "$B#k(B")
    ("Zl" "$B#l(B") ("Zm" "$B#m(B") ("Zn" "$B#n(B") ("Zo" "$B#o(B")
    ("Zp" "$B#p(B") ("Zq" "$B#q(B") ("Zr" "$B#r(B") ("Zs" "$B#s(B")
    ("Zt" "$B#t(B") ("Zu" "$B#u(B") ("Zv" "$B#v(B") ("Zw" "$B#w(B")
    ("Zx" "$B#x(B") ("Zy" "$B#y(B") ("Zz" "$B#z(B") ("Z{" "$B!P(B")
    ("Z|" "$B!C(B") ("Z}" "$B!Q(B") ("Z~" "$B!A(B") 
    ))


;;; @ end
;;;

(provide 'hepburn)

;;; hepburn.el ends here
