;;; jamato.el --- A Roman to Kana database

;; Copyright (C) 1996 MORIOKA Tomohiko

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Version: $Id: jamato.el,v 0.1 1996/09/18 08:38:11 morioka Exp $
;; Keywords: Roman-to-Kana, input, Japanese, mule

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(defvar jamato-roman-to-kana-translation-rule-alist
  '(("a" . "$B$"(B")
    ("i" . "$B$$(B")
    ("u" . "$B$&(B")
    ("e" . "$B$((B")
    ("o" . "$B$*(B")
    
    ("ka" . "$B$+(B")
    ("ki" . "$B$-(B")
    ("ku" . "$B$/(B")
    ("ke" . "$B$1(B")
    ("ko" . "$B$3(B")
    
    ("ga" . "$B$,(B")
    ("gi" . "$B$.(B")
    ("gu" . "$B$0(B")
    ("ge" . "$B$2(B")
    ("go" . "$B$4(B")
    
    ("kja" . "$B$-$c(B")
    ("kji" . "$B$-$#(B")
    ("kju" . "$B$-$e(B")
    ("kje" . "$B$-$'(B")
    ("kjo" . "$B$-$g(B")
    
    ("gja" . "$B$.$c(B")
    ("gji" . "$B$.$#(B")
    ("gju" . "$B$.$e(B")
    ("gje" . "$B$.$'(B")
    ("gjo" . "$B$.$g(B")
    
    ("sa" . "$B$5(B")
    ("si" . "$B$7(B")
    ("su" . "$B$9(B")
    ("se" . "$B$;(B")
    ("so" . "$B$=(B")
    
    ("za" . "$B$6(B")
    ("zi" . "$B$8(B")
    ("zu" . "$B$:(B")
    ("ze" . "$B$<(B")
    ("zo" . "$B$>(B")
    
    ("sja" . "$B$7$c(B")
    ("sji" . "$B$7(B")
    ("sju" . "$B$7$e(B")
    ("sje" . "$B$7$'(B")
    ("sjo" . "$B$7$g(B")
    
    ("zja" . "$B$8$c(B")
    ("zji" . "$B$8$#(B")
    ("zju" . "$B$8$e(B")
    ("zje" . "$B$8$'(B")
    ("zjo" . "$B$8$g(B")
    
    ("ta" . "$B$?(B")
    ("ti" . "$B$F$#(B")
    ("tu" . "$B$H$%(B")
    ("te" . "$B$F(B")
    ("to" . "$B$H(B")
    
    ("da" . "$B$@(B")
    ("di" . "$B$G$#(B")
    ("du" . "$B$E(B")
    ("de" . "$B$G(B")
    ("do" . "$B$I(B")
    
    ("tsa" . "$B$D$!(B")
    ("tsi" . "$B$D$#(B")
    ("tsu" . "$B$D(B")
    ("tse" . "$B$D$'(B")
    ("tso" . "$B$D$)(B")
    
    ("dza" . "$B$E$!(B")
    ("dzi" . "$B$E$#(B")
    ("dzu" . "$B$E(B")
    ("dze" . "$B$E$'(B")
    ("dzo" . "$B$E$)(B")
    
    ("ca" . "$B$A$c(B")
    ("ci" . "$B$A(B")
    ("cu" . "$B$A$e(B")
    ("ce" . "$B$A$'(B")
    ("co" . "$B$A$g(B")
    
    ("dja" . "$B$B$c(B")
    ("dji" . "$B$B(B")
    ("dju" . "$B$B$e(B")
    ("dje" . "$B$B$'(B")
    ("djo" . "$B$B$g(B")
    
    ("na" . "$B$J(B")
    ("ni" . "$B$K(B")
    ("nu" . "$B$L(B")
    ("ne" . "$B$M(B")
    ("no" . "$B$N(B")
    
    ("nja" . "$B$K$c(B")
    ("nji" . "$B$K$#(B")
    ("nju" . "$B$K$e(B")
    ("nje" . "$B$K$'(B")
    ("njo" . "$B$K$g(B")
        
    ("ha" . "$B$O(B")
    ("hi" . "$B$R(B")
    ("hu" . "$B$U(B")
    ("he" . "$B$X(B")
    ("ho" . "$B$[(B")
    
    ("pa" . "$B$Q(B")
    ("pi" . "$B$T(B")
    ("pu" . "$B$W(B")
    ("pe" . "$B$Z(B")
    ("po" . "$B$](B")
    
    ("ba" . "$B$P(B")
    ("bi" . "$B$S(B")
    ("bu" . "$B$V(B")
    ("be" . "$B$Y(B")
    ("bo" . "$B$\(B")
    
    ("hja" . "$B$R$c(B")
    ("hji" . "$B$R$#(B")
    ("hju" . "$B$R$e(B")
    ("hje" . "$B$R$'(B")
    ("hjo" . "$B$R$g(B")
    
    ("pja" . "$B$T$c(B")
    ("pji" . "$B$T$#(B")
    ("pju" . "$B$T$e(B")
    ("pje" . "$B$T$'(B")
    ("pjo" . "$B$T$g(B")
    
    ("bja" . "$B$S$c(B")
    ("bji" . "$B$S$#(B")
    ("bju" . "$B$S$e(B")
    ("bje" . "$B$S$'(B")
    ("bjo" . "$B$S$g(B")
    
    ("fa" . "$B$U$!(B")
    ("fi" . "$B$U$#(B")
    ("fu" . "$B$U(B")
    ("fe" . "$B$U$'(B")
    ("fo" . "$B$U$)(B")
    
    ("pfa" . "$B$W$!(B")
    ("pfi" . "$B$W$#(B")
    ("pfu" . "$B$W(B")
    ("pfe" . "$B$W$'(B")
    ("pfo" . "$B$W$)(B")
    
    ("va" . "$B%t$!(B")
    ("vi" . "$B%t$#(B")
    ("vu" . "$B%t(B")
    ("ve" . "$B%t$'(B")
    ("vo" . "$B%t$)(B")
    
    ("ma" . "$B$^(B")
    ("mi" . "$B$_(B")
    ("mu" . "$B$`(B")
    ("me" . "$B$a(B")
    ("mo" . "$B$b(B")
    
    ("ja" . "$B$d(B")
    ("ji" . "$B$$(B")
    ("ju" . "$B$f(B")
    ("je" . "$B$$$'(B")
    ("jo" . "$B$h(B")
    
    ("la" . "$B$i(B")
    ("li" . "$B$j(B")
    ("lu" . "$B$k(B")
    ("le" . "$B$l(B")
    ("lo" . "$B$m(B")
    
    ("wa" . "$B$o(B")
    ("wi" . "$B$p(B")
    ("wu" . "$B$&(B")
    ("we" . "$B$q(B")
    ("wo" . "$B$r(B")
    
    ("x" . "$B$s(B")
    ("q" . "$B$C(B")
    ("r" . "$B!<(B")
    ("." . "$B!#(B")
    ("," . "$B!"(B")
    ("?" . "$B!)(B")
    (";" . "$B!((B")
    (":" . "$B!'(B")
    ("(" . "$B!J(B")
    (")" . "$B!K(B")
    ("@" . "$B!w(B")
    (" " . " ")
    ))


;;; @ end
;;;

(provide 'jamato)

;;; jamato.el ends here
