;;; roman-to-kana.el --- Roman to Kana converter

;; Copyright (C) 1996 MORIOKA Tomohiko

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Version: $Id: roman-to-kana.el,v 0.1 1996/09/17 06:19:22 morioka Exp $
;; Keywords: Roman-to-Kana, input, Japanese, mule

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(require 'tl-seq)
(require 'tl-str)

(defvar roman-to-kana-translate-table 'hepburn)

(require roman-to-kana-translate-table)

(defun roman-to-kana-string-1 (str table)
  (let ((ret
	 (find-if (function
		   (lambda (rule)
		     (top-string-match (car rule) str)
		     ))
		  table)))
    (if ret
	(cons (cdr ret)(substring str (match-end 0)))
      )
    ))

(defun roman-to-kana-translate-string (str &optional table)
  (or table
      (setq table (symbol-value
		   (intern (concat
			   (symbol-name roman-to-kana-translate-table)
			   "-roman-to-kana-translation-rule-alist"))
		   )))
  (let (ret dest)
    (while (setq ret (roman-to-kana-string-1 str table))
      (setq dest (concat dest (car ret)))
      (setq str (cdr ret))
      )
    (concat dest str)
    ))

(defun roman-to-kana-translate-region (start end)
  (save-excursion
    (let ((str (buffer-substring start end)))
      (delete-region start end)
      (goto-char start)
      (insert (roman-to-kana-translate-string str))
      )))


;;; @ end
;;;

(provide 'roman-to-kana)

;;; roman-to-kana.el ends here
