;;; yude-kkc.el --- Boiled-Egg like roman to kanaji converter

;; Copyright (C) 1996 MORIOKA Tomohiko

;; Author: MORIOKA Tomohiko <morioka@jaist.ac.jp>
;; Version: $Id: yude-kkc.el,v 0.1 1996/09/18 08:36:11 morioka Exp $
;; Keywords: input, Japanese, mule

;; This file is not part of GNU Emacs.

;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 2, or (at
;; your option) any later version.

;; This program is distributed in the hope that it will be useful, but
;; WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
;; Boston, MA 02111-1307, USA.

;;; Code:

(require 'roman-to-kana)
(require 'kkc)

(defvar kkc-boiled-charset "-a-zA-Z0-9.,?!~()[]#@/:"
  "*characters to transfer. [yude-kkc.el]")

(defvar yude-kkc-kanji-key "\e ")
(defvar yude-kkc-hiragana-key "\ej")

(global-set-key yude-kkc-kanji-key 'yude-kkc-translate-to-kanji)
(global-set-key yude-kkc-hiragana-key 'yude-kkc-translate-to-hiragana)

(defun yude-kkc-translate-region (start end)
  (let ((e (save-excursion
	     (save-restriction
	       (narrow-to-region start end)
	       (roman-to-kana-translate-region start end)
	       (point-max)
	       ))))
    (kkc-region start e)
    ))

(defun yude-kkc-translate-to-kanji (arg)
  (interactive "p")
  (let ((po (point)) (mark (or (mark t) 0)))
    (skip-chars-backward kkc-boiled-charset)
    (if (and mark (< mark po) (< (point) mark))
	(goto-char mark)
      )
    (if (not (eq (point) po))
	(yude-kkc-translate-region (point) po)
      )
    ))

(defun yude-kkc-translate-to-hiragana (arg)
  (interactive "p")
  (let ((po (point)) (mark (or (mark t) 0)))
    (skip-chars-backward kkc-boiled-charset)
    (if (and mark (< mark po) (< (point) mark))
	(goto-char mark)
      )
    (if (not (eq (point) po))
	(save-restriction
	  (narrow-to-region (point) po)
	  (roman-to-kana-translate-region (point) po)
	  (goto-char (point-max))
	  ))
    ))


;;; @ end
;;;

(provide 'yude-kkc)

;;; yude-kkc.el ends here
